Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(213)

Unified Diff: chrome/browser/autofill/risk/fingerprint.h

Issue 12212057: [Autofill] Add ability to load Risk fingerprint data in AutofillDialogControllerImpl. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autofill/risk/fingerprint.h
diff --git a/chrome/browser/autofill/risk/fingerprint.h b/chrome/browser/autofill/risk/fingerprint.h
index 9aae177d034a18d8cfe195040675ea52c3d872d4..6ec20eb3ee7ed146a2a5813b0683b574f14ca999 100644
--- a/chrome/browser/autofill/risk/fingerprint.h
+++ b/chrome/browser/autofill/risk/fingerprint.h
@@ -11,6 +11,10 @@
class PrefServiceBase;
+namespace content {
+class WebContents;
+}
+
namespace gfx {
class Rect;
}
@@ -28,14 +32,12 @@ class Fingerprint;
// unique fingerprint for this (machine, user) pair, used for fraud prevention.
// The |gaia_id| should be the user id for Google's authentication system.
// The |window_bounds| should be the bounds of the containing Chrome window.
// The |content_bounds| should be the bounds of the web contents view for the
// page the user is interacting with. The |prefs| should reflect the active
// Chrome profile's user preferences.
void GetFingerprint(
int64 gaia_id,
const gfx::Rect& window_bounds,
- const gfx::Rect& content_bounds,
- const WebKit::WebScreenInfo& screen_info,
+ const content::WebContents& web_contents,
const PrefServiceBase& prefs,
const base::Callback<void(scoped_ptr<Fingerprint>)>& callback);
@@ -28,14 +32,12 @@ class Fingerprint;
// The |gaia_id| should be the user id for Google's authentication system.
// The |window_bounds| should be the bounds of the containing Chrome window.
-// The |content_bounds| should be the bounds of the web contents view for the
-// page the user is interacting with. The |prefs| should reflect the active
-// Chrome profile's user preferences.
+// The |web_contents| should be host for the page the user is interacting with.
+// The |prefs| should reflect the active Chrome profile's user preferences.
void GetFingerprint(
int64 gaia_id,

Powered by Google App Engine
This is Rietveld 408576698